You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2014/03/10 15:41:40 UTC

svn commit: r1575954 - /subversion/trunk/subversion/libsvn_repos/load.c

Author: julianfoad
Date: Mon Mar 10 14:41:40 2014
New Revision: 1575954

URL: http://svn.apache.org/r1575954
Log:
* subversion/libsvn_repos/load.c
  Remove unused #include's.
  (parse_text_block): Bring the doc string up to date.

Modified:
    subversion/trunk/subversion/libsvn_repos/load.c

Modified: subversion/trunk/subversion/libsvn_repos/load.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_repos/load.c?rev=1575954&r1=1575953&r2=1575954&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_repos/load.c (original)
+++ subversion/trunk/subversion/libsvn_repos/load.c Mon Mar 10 14:41:40 2014
@@ -21,26 +21,18 @@
  */
 
 
-#include "svn_private_config.h"
+#include <apr.h>
+
 #include "svn_hash.h"
 #include "svn_pools.h"
 #include "svn_error.h"
-#include "svn_fs.h"
 #include "svn_repos.h"
 #include "svn_string.h"
-#include "svn_path.h"
-#include "svn_props.h"
 #include "repos.h"
 #include "svn_private_config.h"
-#include "svn_mergeinfo.h"
-#include "svn_checksum.h"
-#include "svn_subst.h"
 #include "svn_ctype.h"
 
-#include <apr_lib.h>
-
 #include "private/svn_dep_compat.h"
-#include "private/svn_mergeinfo_private.h"
 
 /*----------------------------------------------------------------------*/
 
@@ -291,7 +283,8 @@ parse_property_block(svn_stream_t *strea
 }
 
 
-/* Read CONTENT_LENGTH bytes from STREAM, and use
+/* Read CONTENT_LENGTH bytes from STREAM. If IS_DELTA is true, use
+   PARSE_FNS->apply_textdelta to push a text delta, otherwise use
    PARSE_FNS->set_fulltext to push those bytes as replace fulltext for
    a node.  Use BUFFER/BUFLEN to push the fulltext in "chunks".